@@ -22,8 +22,8 @@ moves <- groupMovements(detections.list = detections.list[1:2], bio = bio, spati
     speed.method = "last to first", max.interval = 60, tz = "Europe/Copenhagen", dist.mat = dist.mat)
 
 aux <- names(moves)
-moves <- lapply(names(moves), function(fish) {
-    speedReleaseToFirst(fish = fish, bio = bio, movements = moves[[fish]],
+moves <- lapply(names(moves), function(tag) {
+    speedReleaseToFirst(tag = tag, bio = bio, movements = moves[[tag]],
                         dist.mat = dist.mat, speed.method = "last to first")
   })
 names(moves) <- aux
@@ -33,10 +33,10 @@ test_that("checkMinimumN reacts as expected", {
 	xmoves <- moves
 	xmoves[[1]] <- xmoves[[1]][1, ]
 	xmoves[[1]]$Detections <- 1
-  expect_warning(output <- checkMinimumN(movements = xmoves[[1]], fish = "test", minimum.detections = 2),
-  	"Fish test only has one movement event (A1) with 1 detections. Considered invalid.", fixed = TRUE)
+  expect_warning(output <- checkMinimumN(movements = xmoves[[1]], tag = "test", minimum.detections = 2),
+  	"Tag test only has one movement event (A1) with 1 detections. Considered invalid.", fixed = TRUE)
   expect_false(output$Valid)
-  output <- checkMinimumN(movements = xmoves[[2]], fish = "test", minimum.detections = 2)
+  output <- checkMinimumN(movements = xmoves[[2]], tag = "test", minimum.detections = 2)
   expect_true(all(output$Valid))
 })
 
@@ -44,8 +44,8 @@ test_that("checkImpassables reacts as expected", {
  	xdotmat <- dotmat
  	xdotmat["A1", "A2"] <- NA
   expect_error(
-  	expect_warning(output <- checkImpassables(movements = moves[[1]], fish = "test", dotmat = xdotmat, GUI = "never"),
-  		"Fish test made an impassable jump: It is not possible to go from array A1 to A2.", fixed = TRUE), 	
+  	expect_warning(output <- checkImpassables(movements = moves[[1]], tag = "test", dotmat = xdotmat, GUI = "never"),
+  		"Tag test made an impassable jump: It is not possible to go from array A1 to A2.", fixed = TRUE), 	
 		"Preventing analysis from entering interactive mode in a non-interactive session.", fixed = TRUE)
 })
 # 1
@@ -56,36 +56,36 @@ test_that("checkJumpDistance reacts as expected", {
 	# jump from release to first event
 	xmoves <- moves[[1]]
 	xmoves$Array[1] <- "A3"
-	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", fish = "test", dotmat = dotmat,
+	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", tag = "test", dotmat = dotmat,
 	                          jump.warning = 1, jump.error = Inf, GUI = "never"),
-	"Fish test jumped through 2 arrays from release to first valid event (Release -> A3).", fixed = TRUE)
+	"Tag test jumped through 2 arrays from release to first valid event (Release -> A3).", fixed = TRUE)
 
 	# jump from release because first event is invalid
 	xmoves <- moves[[1]]
 	xmoves$Valid[1] <- FALSE
-	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", fish = "test", dotmat = dotmat,
+	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", tag = "test", dotmat = dotmat,
 	                          jump.warning = 1, jump.error = Inf, GUI = "never"),
-	"Fish test jumped through 1 array from release to first valid event (Release -> A2).", fixed = TRUE)
+	"Tag test jumped through 1 array from release to first valid event (Release -> A2).", fixed = TRUE)
 
 	# jump from first to second event
 	xmoves <- moves[[1]]
 	xmoves$Array[2] <- "A3"
-	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", fish = "test", dotmat = dotmat,
+	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", tag = "test", dotmat = dotmat,
 	                          jump.warning = 1, jump.error = Inf, GUI = "never"),
-	"Fish test jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
+	"Tag test jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
 	
 	# jump from first to third because second is invalid
 	xmoves <- moves[[1]]
 	xmoves$Array[2] <- "Unknown"
 	xmoves$Valid[2] <- FALSE
-	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", fish = "test", dotmat = dotmat,
+	expect_warning(checkJumpDistance(movements = xmoves, release = "A1", tag = "test", dotmat = dotmat,
 	                          jump.warning = 1, jump.error = Inf, GUI = "never"),
-	"Fish test jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
+	"Tag test jumped through 1 array in valid events 1 -> 2 (A1 -> A3)", fixed = TRUE)
 
 	# Impassable jump exception
 	xdotmat <- dotmat
  	xdotmat["A1", "A2"] <- NA
-	expect_error(checkJumpDistance(movements = moves[[1]], release = "A1", fish = "test", dotmat = xdotmat,
+	expect_error(checkJumpDistance(movements = moves[[1]], release = "A1", tag = "test", dotmat = xdotmat,
 	                          jump.warning = 1, jump.error = Inf, GUI = "never"),
 	"There are unresolved impassable jumps in the movements.", fixed = TRUE)
 
@@ -97,19 +97,19 @@ test_that("checkSpeeds reacts as expected.", {
 	# speed warning from release
 	xmoves <- moves[[1]]
 	xmoves$Average.speed.m.s[1] <- 3
-	expect_warning(output <- checkSpeeds(movements = xmoves, fish = "test", valid.movements = xmoves,
+	expect_warning(output <- checkSpeeds(movements = xmoves, tag = "test", valid.movements = xmoves,
     speed.warning = 3, speed.error = Inf, GUI = "never"),
-	"Fish test had an average speed of 3 m/s from release to first valid event (Release -> A1)", fixed = TRUE)
+	"Tag test had an average speed of 3 m/s from release to first valid event (Release -> A1)", fixed = TRUE)
 	expect_equal(output, xmoves)
 
 	# speed warning between movements
-	expect_warning(output <- checkSpeeds(movements = moves[[1]], fish = "test", valid.movements = moves[[1]],
+	expect_warning(output <- checkSpeeds(movements = moves[[1]], tag = "test", valid.movements = moves[[1]],
     speed.warning = 2, speed.error = Inf, GUI = "never"),
-	"Fish test had an average speed of 2.12 m/s from valid event 4 to 5 (A4 -> A5)", fixed = TRUE)
+	"Tag test had an average speed of 2.12 m/s from valid event 4 to 5 (A4 -> A5)", fixed = TRUE)
 	expect_equal(output, moves[[1]])
 
 	# no warnings, runs smoothly
-	output <- checkSpeeds(movements = moves[[1]], fish = "test", valid.movements = moves[[1]],
+	output <- checkSpeeds(movements = moves[[1]], tag = "test", valid.movements = moves[[1]],
     speed.warning = Inf, speed.error = Inf, GUI = "never")
 	expect_equal(output, moves[[1]])
 })
@@ -117,39 +117,39 @@ test_that("checkSpeeds reacts as expected.", {
 test_that("checkInactiveness reacts as expected.", {
   xmoves <- moves[[1]][-c(17, 18), ]
   # With distances
-  expect_warning(output <- checkInactiveness(movements = xmoves, fish = "test", detections.list = detections.list[[1]],
+  expect_warning(output <- checkInactiveness(movements = xmoves, tag = "test", detections.list = detections.list[[1]],
     inactive.warning = 1, inactive.error = Inf, dist.mat = dist.mat, GUI = "never"),
-  "Fish test was detected 292 times at stations less than 1.5 km apart in array 'A7' (St.9, St.10, St.11), over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
+  "Tag test was detected 292 times at stations less than 1.5 km apart in array 'A7' (St.9, St.10, St.11), over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
   expect_equal(output, xmoves)
 
   # Without distances
   xdist <- dist.mat
   attributes(xdist)$valid <- FALSE
-  expect_warning(output <- checkInactiveness(movements = xmoves, fish = "test", detections.list = detections.list[[1]],
+  expect_warning(output <- checkInactiveness(movements = xmoves, tag = "test", detections.list = detections.list[[1]],
     inactive.warning = 1, inactive.error = Inf, dist.mat = xdist, GUI = "never"),
-  "Fish test was detected 292 times at three or less stations of array 'A7' (St.9, St.10, St.11) over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
+  "Tag test was detected 292 times at three or less stations of array 'A7' (St.9, St.10, St.11) over 2.57 days and then disappeared. Could it be inactive?", fixed = TRUE)
   expect_equal(output, xmoves)
 
   # no warnings
-  output <- checkInactiveness(movements = xmoves, fish = "test", detections.list = detections.list[[1]],
+  output <- checkInactiveness(movements = xmoves, tag = "test", detections.list = detections.list[[1]],
     inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never")
   expect_equal(output, xmoves)
 
   # internal code option for no shifts
   xmoves <- moves[[1]][-c(1:6, 17, 18), ]
-  output <- checkInactiveness(movements = xmoves, fish = "test", detections.list = detections.list[[1]],
+  output <- checkInactiveness(movements = xmoves, tag = "test", detections.list = detections.list[[1]],
     inactive.warning = Inf, inactive.error = Inf, dist.mat = xdist, GUI = "never")
   expect_equal(output, xmoves)
 })
 
 test_that("checkUpstream reacts as expected.", {
-  tryCatch(x <- checkUpstream(movements = moves[[1]], fish = "test", release = "A1", arrays = arrays, GUI = "never"),
+  tryCatch(x <- checkUpstream(movements = moves[[1]], tag = "test", release = "A1", arrays = arrays, GUI = "never"),
     warning = function(w) stop("A warning was issued where it should not have been."))
-  expect_warning(checkUpstream(movements = moves[[1]], fish = "test", release = "A2", arrays = arrays, GUI = "never"),
-    "Fish test was detected in an array that is not after its release site! Opening relevant data for inspection.\nExpected first array: A2", fixed = TRUE)
+  expect_warning(checkUpstream(movements = moves[[1]], tag = "test", release = "A2", arrays = arrays, GUI = "never"),
+    "Tag test was detected in an array that is not after its release site! Opening relevant data for inspection.\nExpected first array: A2", fixed = TRUE)
   xmoves <- moves[[1]]
   xmoves$Valid <- FALSE
-  tryCatch(output <- checkUpstream(movements = xmoves, fish = "test", release = "A2", arrays = arrays, GUI = "never"),
+  tryCatch(output <- checkUpstream(movements = xmoves, tag = "test", release = "A2", arrays = arrays, GUI = "never"),
     warning = function(w) stop("A warning was issued where it should not have been."))
   expect_equal(output, xmoves)
 })
@@ -157,14 +157,14 @@ test_that("checkUpstream reacts as expected.", {
 
 test_that("simplifyMovements works as expected.", {
 	# no invalid events
-  output <- simplifyMovements(movements = moves[[1]], fish = "R64K-4451", bio = bio, discard.first = NULL,
+  output <- simplifyMovements(movements = moves[[1]], tag = "R64K-4451", bio = bio, discard.first = NULL,
     speed.method = "last to first", dist.mat = dist.mat)
   expect_equal(output, moves[[1]])
   # invalid events
   xmoves <- moves[[1]]
   xmoves$Valid <- rep(c(TRUE, FALSE), 9)
   # With dist.mat
-  output <- simplifyMovements(movements = xmoves, fish = "R64K-4451", bio = bio, discard.first = NULL,
+  output <- simplifyMovements(movements = xmoves, tag = "R64K-4451", bio = bio, discard.first = NULL,
     speed.method = "last to first", dist.mat = dist.mat)
   expect_equal(nrow(output), 9)
   expect_equal(output$Array, xmoves$Array[(1:9 * 2) - 1])
@@ -178,7 +178,7 @@ test_that("simplifyMovements works as expected.", {
   # Without dist.mat
   xdist <- dist.mat
   attributes(xdist)$valid <- FALSE
-  output <- simplifyMovements(movements = xmoves, fish = "R64K-4451", bio = bio, discard.first = NULL,
+  output <- simplifyMovements(movements = xmoves, tag = "R64K-4451", bio = bio, discard.first = NULL,
     speed.method = "last to first", dist.mat = xdist)
   expect_equal(nrow(output), 9)
   expect_equal(output$Array, xmoves$Array[(1:9 * 2) - 1])
@@ -188,7 +188,7 @@ test_that("simplifyMovements works as expected.", {
   # Fully invalid
   xmoves <- moves[[1]]
   xmoves$Valid <- FALSE
-  output <- simplifyMovements(movements = xmoves, fish = "R64K-4451", bio = bio, discard.first = NULL,
+  output <- simplifyMovements(movements = xmoves, tag = "R64K-4451", bio = bio, discard.first = NULL,
     speed.method = "last to first", dist.mat = xdist)
   expect_equal(output, NULL)
 })
@@ -196,7 +196,7 @@ test_that("simplifyMovements works as expected.", {
 test_that("validateDetections works as expected.", {
   xmoves <- moves[[1]]
   xmoves$Valid <- rep(c(TRUE, FALSE), 9)
-  vm <- list("R64K-4451" = simplifyMovements(movements = xmoves, fish = "R64K-4451", bio = bio, discard.first = NULL,
+  vm <- list("R64K-4451" = simplifyMovements(movements = xmoves, tag = "R64K-4451", bio = bio, discard.first = NULL,
     speed.method = "last to first", dist.mat = dist.mat))
   vd <- validateDetections(detections.list = detections.list, movements = vm)[[2]]
   expect_equal(sum(moves[[1]]$Detections), nrow(detections.list[[1]]))
