@@ -27,6 +27,9 @@ test_that("extractCodeSpaces is working", {
 })
 
 test_that("stationName is working", {
+	expect_error(stationName("a"), "Could not recognise the input as an actel results object.")
+	expect_error(stationName(list("a")), "Could not recognise the input as an actel results object.")
+
 	expect_equal(stationName(example.results, 2:3), c("Station 1", "Station 2"))
 })
 
@@ -85,9 +88,9 @@ test_that("roundUp works as expected.", {
 })
 
 test_that("appendTo stores comments.", {
-	appendTo("Comment", "test comment", "Test fish")
+	appendTo("Comment", "test comment", "Test tag")
 	expect_true(file.exists("temp_comments.txt"))
-	expect_equal(read.table("temp_comments.txt", sep = "\t"), read.csv(text = '"V1","V2"\n"Test fish","test comment"'))
+	expect_equal(read.table("temp_comments.txt", sep = "\t"), read.csv(text = '"V1","V2"\n"Test tag","test comment"'))
 	file.remove("temp_comments.txt")
 })
 
